@@ -1,7 +1,7 @@
 from .core.STDataset import STDataset
 from .run import run
 
-from .core.io import load_10X
+from .core.io import load_10X, load_anndata_h5
 from . import filters, normalizers, plot
 
 from ._version import __version__
@@ -10,6 +10,7 @@ __all__ = [
     "STDataset",
     "run",
     "load_10X",
+    "load_anndata_h5",
     "filters",
     "normalizers",
     "plot",
